Interface ConnectionFactory

All Known Implementing Classes:
DriverManagerConnectionFactory
Functional Interface:
This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.

@FunctionalInterface public interface ConnectionFactory
A ConnectionFactory combines a set of connection configuration parameters that have been defined prior to connection creation.
  • Method Summary

    Modifier and Type
    Method
    Description
    create(String jdbcUrl, Properties properties)
    Creates a fresh connection to the specified database
  • Method Details

    • create

      Connection create(String jdbcUrl, Properties properties)
      Creates a fresh connection to the specified database
      Parameters:
      jdbcUrl - the JDBC url.
      properties - the properties.
      Returns:
      a new Connection.