Record Class SqlQueryExecutorConfiguration

java.lang.Object
java.lang.Record
org.eclipse.edc.sql.SqlQueryExecutorConfiguration

public record SqlQueryExecutorConfiguration(int fetchSize) extends Record
Configuration class for SqlQueryExecutor
  • Field Details

  • Constructor Details

    • SqlQueryExecutorConfiguration

      public SqlQueryExecutorConfiguration(int fetchSize)
      Creates an instance of a SqlQueryExecutorConfiguration record class.
      Parameters:
      fetchSize - the value for the fetchSize record component
  • Method Details

    • ofDefaults

      public static SqlQueryExecutorConfiguration ofDefaults()
    • toString

      public final String toString()
      Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components.
      Specified by:
      toString in class Record
      Returns:
      a string representation of this object
    • hashCode

      public final int hashCode()
      Returns a hash code value for this object. The value is derived from the hash code of each of the record components.
      Specified by:
      hashCode in class Record
      Returns:
      a hash code value for this object
    • equals

      public final boolean equals(Object o)
      Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared with '=='.
      Specified by:
      equals in class Record
      Parameters:
      o - the object with which to compare
      Returns:
      true if this object is the same as the o argument; false otherwise.
    • fetchSize

      public int fetchSize()
      Returns the value of the fetchSize record component.
      Returns:
      the value of the fetchSize record component