Class PostgresDialect

java.lang.Object
org.eclipse.edc.sql.dialect.PostgresDialect

public class PostgresDialect extends Object
Global, domain-agnostic Postgres statements, operators, functions, clauses, etc.
  • Constructor Details

    • PostgresDialect

      public PostgresDialect()
  • Method Details

    • getSelectFromJsonArrayTemplate

      public static String getSelectFromJsonArrayTemplate(String selectStatement, String jsonPath, String aliasName)
      Creates a SELECT statement that targets a Postgres JSON array
      Parameters:
      selectStatement - The select statement, does not include the json_array_elements function call
      jsonPath - The path to the array object, which is passed as parameter to the json_array_elements() function
      aliasName - the alias under which the JSON array is available, e.g. for WHERE clauses
    • getJsonCastOperator

      public static String getJsonCastOperator()
      Returns the Postgres operator to cast a varchar to json ("::json")