Record Class ColumnEntry

java.lang.Object
java.lang.Record
org.eclipse.edc.sql.statement.ColumnEntry
Record Components:
columnName - the name of the column.
value - the value of the column, by default it will be '?' but it could be different.

public record ColumnEntry(String columnName, String value) extends Record
Represent a column and its value into a JDBC prepared statement.
  • Constructor Details

    • ColumnEntry

      public ColumnEntry(String columnName, String value)
      Creates an instance of a ColumnEntry record class.
      Parameters:
      columnName - the value for the columnName record component
      value - the value for the value record component
  • Method Details

    • standardColumn

      public static ColumnEntry standardColumn(String columnName)
    • jsonColumn

      public static ColumnEntry jsonColumn(String columnName, String jsonOperator)
    • append

      public ColumnEntry append(ColumnEntry other)
    • asString

      public String asString()
    • toString

      public final String toString()
      Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components.
      Specified by:
      toString in class Record
      Returns:
      a string representation of this object
    • hashCode

      public final int hashCode()
      Returns a hash code value for this object. The value is derived from the hash code of each of the record components.
      Specified by:
      hashCode in class Record
      Returns:
      a hash code value for this object
    • equals

      public final boolean equals(Object o)
      Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared with Objects::equals(Object,Object).
      Specified by:
      equals in class Record
      Parameters:
      o - the object with which to compare
      Returns:
      true if this object is the same as the o argument; false otherwise.
    • columnName

      public String columnName()
      Returns the value of the columnName record component.
      Returns:
      the value of the columnName record component
    • value

      public String value()
      Returns the value of the value record component.
      Returns:
      the value of the value record component