Interface SqlStatements


public interface SqlStatements
Provide base SQL functionalities.
  • Method Details

    • getFormatAsJsonOperator

      default String getFormatAsJsonOperator()
      Operator to format an incoming string as JSON. Should return an empty string if the database does not support this. By default, it's the one used by H2, but every different implementation could then override this method with the correct operator.
      Returns:
      JSON cast operator
    • executeStatement

      default SqlExecuteStatement executeStatement()
      Instantiate a new execute statement using the correct JSON operator.
      Returns:
      the SqlExecuteStatement.