Package org.eclipse.edc.sql.statement
package org.eclipse.edc.sql.statement
-
ClassDescriptionRepresent a column and its value into a JDBC prepared statement.Helps in constructing SQL insert/update statements without having to deal with the SQL syntax directlyProvide base SQL functionalities.