Package org.eclipse.edc.sql.dialect
Class PostgresDialect
java.lang.Object
org.eclipse.edc.sql.dialect.PostgresDialect
Global, domain-agnostic Postgres statements, operators, functions, clauses, etc.
-
Constructor Summary
Constructors -
Method Summary
-
Constructor Details
-
PostgresDialect
public PostgresDialect()
-
-
Method Details
-
getSelectFromJsonArrayTemplate
public static String getSelectFromJsonArrayTemplate(String selectStatement, String jsonPath, String aliasName) Creates a SELECT statement that targets a Postgres JSON array- Parameters:
selectStatement- The select statement, does not include thejson_array_elementsfunction calljsonPath- The path to the array object, which is passed as parameter to thejson_array_elements()functionaliasName- the alias under which the JSON array is available, e.g. for WHERE clauses
-
getJsonCastOperator
Returns the Postgres operator to cast a varchar to json ("::json")
-