Package org.eclipse.edc.sql.statement
Record Class ColumnEntry
java.lang.Object
java.lang.Record
org.eclipse.edc.sql.statement.ColumnEntry
- Record Components:
columnName- the name of the column.value- the value of the column, by default it will be '?' but it could be different.
Represent a column and its value into a JDBC prepared statement.
-
Constructor Summary
ConstructorsConstructorDescriptionColumnEntry(String columnName, String value) Creates an instance of aColumnEntryrecord class. -
Method Summary
Modifier and TypeMethodDescriptionappend(ColumnEntry other) asString()Returns the value of thecolumnNamerecord component.final booleanIndicates whether some other object is "equal to" this one.final inthashCode()Returns a hash code value for this object.static ColumnEntryjsonColumn(String columnName, String jsonOperator) static ColumnEntrystandardColumn(String columnName) final StringtoString()Returns a string representation of this record class.value()Returns the value of thevaluerecord component.
-
Constructor Details
-
ColumnEntry
Creates an instance of aColumnEntryrecord class.- Parameters:
columnName- the value for thecolumnNamerecord componentvalue- the value for thevaluerecord component
-
-
Method Details
-
standardColumn
-
jsonColumn
-
append
-
asString
-
toString
Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components. -
hashCode
public final int hashCode()Returns a hash code value for this object. The value is derived from the hash code of each of the record components. -
equals
Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared withObjects::equals(Object,Object). -
columnName
Returns the value of thecolumnNamerecord component.- Returns:
- the value of the
columnNamerecord component
-
value
Returns the value of thevaluerecord component.- Returns:
- the value of the
valuerecord component
-